@@ -5,7 +5,7 @@ N <- 10000
 X <- cbind(rnorm(N, mean=3, sd=1),
            rnorm(N, mean=4, sd=2),
            rgamma(N, shape=2, rate=1))
-X[sample(3*N, size=0.20*3*N)] <- NA
+X[sample(3*N, size=0.20*3*N)] <- NA_real_
 
 # Normalize quantiles
 Xn <- normalizeAverage(X, na.rm=TRUE, targetAvg=median(X, na.rm=TRUE))
