@@ -11,14 +11,14 @@ for (kk in 1:8) {
   values <- rfcn(size*N, a, b)
 
   # "Censor" values
-  values[values < 0 | values > 8] <- NA
+  values[values < 0 | values > 8] <- NA_real_
 
   X[[kk]] <- values
 }
 
 # Add 20% missing values
 X <- lapply(X, FUN=function(x) {
-  x[sample(length(x), size=0.20*length(x))] <- NA;
+  x[sample(length(x), size=0.20*length(x))] <- NA_real_
   x
 })
 
@@ -27,6 +27,6 @@ Xn <- normalizeQuantile(X)
 
 # Plot the data
 layout(matrix(1:2, ncol=1))
-xlim <- range(X, na.rm=TRUE);
+xlim <- range(X, na.rm=TRUE)
 plotDensity(X, lwd=2, xlim=xlim, main="The original distributions")
 plotDensity(Xn, lwd=2, xlim=xlim, main="The normalized distributions")
